@@ -552,6 +552,9 @@ class Douglas_peucker(object):
         for i in range(0, len(pointlist)):
             pointlist[i] = self.DouglasPeucker(pointlist[i], self.EPSILON)
         handwritten_data.set_pointlist(pointlist)
+        # This might have duplicated points! Filter them!
+        alg = Remove_points()
+        alg(handwritten_data)
 
 
 class Stroke_connect(object):
